@@ -17,7 +17,7 @@ if (APACHE2) {
 else { require Apache }
 require Apache::Request;
 
-our $VERSION = "0.4";
+our $VERSION = "2.03";
 
 sub get_request {
     my ( $self, $r ) = @_;
@@ -43,7 +43,9 @@ sub parse_args {
 sub send_output {
     my $r = shift;
     $r->{ar}->content_type(
-        $r->{content_type} . "; charset=" . $r->{document_encoding} );
+        $r->{content_type}  =~ m/^text/ ?
+	$r->{content_type} . "; charset=" . $r->{document_encoding} :
+	$r->{content_type} );
     $r->{ar}->headers_out->set( "Content-Length" => length $r->{output} );
     APACHE2 || $r->{ar}->send_http_header;
     $r->{ar}->print( $r->{output} );
